@@ -66,6 +66,8 @@ def format_insert_key(signature, func_name, args, params):
     if param_keys and args:
         if param_keys[0] == "self":
             _args = args[1:]
+    if isinstance(_args, tuple):
+        _args = list(_args)
     for k in params:
         _args.append(json.dumps(params[k]))
     str_insert_key = "&".join([str(x) for x in _args])
